@@ -14,6 +14,7 @@ init()
 
 from .utils import deep_merge, send_email, get, cast
 from .exception import AppToolError
+from .ColorfulFormatter import ColorfulFormatter
 
 
 class MySMTPHandler(handlers.SMTPHandler):
@@ -164,7 +165,7 @@ class AppTool(object):
         fileDest = logDst.get('file', 1)
         if fileDest == 1:
             regular_log_name = re.sub(r'\W+', '_', self._app_name.lower())
-            rf_handler = handlers.TimedRotatingFileHandler(path.join(logs_path, f'{regular_log_name}.log'), when='D', interval=1, backupCount=7)
+            rf_handler = handlers.TimedRotatingFileHandler(path.join(logs_path, f'{regular_log_name}.log'), when='D', interval=1, backupCount=7, encoding='utf-8')
             rf_handler.suffix = "%Y-%m-%d_%H-%M-%S.log"
             rf_handler.level = logging.INFO
             rf_handler.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
@@ -192,7 +193,7 @@ class AppTool(object):
         if stdoutDest == 1:
             st_handler = logging.StreamHandler()
             st_handler.level = logging.DEBUG
-            st_handler.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
+            st_handler.setFormatter(ColorfulFormatter())
             logger.addHandler(st_handler)
         self._logger = logger
         return logger
@@ -252,7 +253,7 @@ class AppTool(object):
 
 
     def fatal(self, msg, *args, **kwargs):
-        self._logger.fatal(msg, *args, **kwargs)
+        self._logger.critical(msg, *args, **kwargs)
         
     
     def D(self, *args):
@@ -282,13 +283,13 @@ class AppTool(object):
     def print(self, level, *args):
         local_time = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime())
         if level == 'DEBUG':
-            header_style = Fore.CYAN
-            fg = ''
+            header_style = Fore.BLUE + Back.WHITE
+            fg = Fore.CYAN
         elif level == 'INFO':
-            header_style = Fore.WHITE + Back.BLUE
+            header_style = Fore.YELLOW + Back.BLUE
             fg = Fore.GREEN
         elif level == 'WARN':
-            header_style = Fore.BLACK + Back.YELLOW
+            header_style = Fore.LIGHTBLUE_EX + Back.YELLOW + Style.BRIGHT
             fg = Fore.YELLOW
         elif level == 'ERROR':
             header_style = Fore.WHITE + Back.RED + Style.BRIGHT
@@ -298,7 +299,7 @@ class AppTool(object):
             fg = Fore.RED
             
         print(Style.DIM + local_time + Style.RESET_ALL + ' '\
-            + header_style + f' {level:>5} ' + Style.RESET_ALL + ' ' + fg, end='')
+            + header_style + f' {level} ' + Style.RESET_ALL + ' ' + fg, end='')
         for obj in args:
             if isinstance(obj, str):
               print(obj, end=' ')
