@@ -531,7 +531,7 @@ def pad_filename(filename:str, pad:str=None, template:str=None)->str:
     return path.join(fpath, template.format(FILENAME=name, FILEEXT=ext[1:], PAD=pad))
 
 
-def run(self, cmd, echo_cmd=False):
+def run(cmd, echo_cmd=False):
     import subprocess
     try:
         if echo_cmd:
@@ -540,4 +540,23 @@ def run(self, cmd, echo_cmd=False):
     except subprocess.CalledProcessError as e:
         result = e.output       # Output generated before error
         #code      = e.returncode   # Return code
-    return str(result, encoding = "utf-8", errors='ignore')
\ No newline at end of file
+    return str(result, encoding = "utf-8", errors='ignore')
+
+
+def demo_logging():
+    from .app_tool import AppTool
+    app = AppTool('pybeans_demo_logging')
+    app.D('this is demo output for debug')
+    app.I('this is demo output for info')
+    app.W('this is demo output for warn')
+    app.E('this is demo output for error')
+
+    app.debug('this is demo output for debug')
+    app.info('this is demo output for info')
+    app.warn('this is demo output for warn')
+    app.error('this is demo output for error')
+    app.fatal('this is demo output for fatal')
+    try:
+        do_nothing()
+    except Exception:
+        app.ex('this is demo output for excatipn')
\ No newline at end of file
